@@ -14,6 +14,13 @@ class SaveAppUtility:
         for vm in self.sandbox.automation_api.GetReservationDetails(self.sandbox.id).ReservationDescription.Resources:
             if vm.Name == self.resource_name:
                 self.app_name = vm.AppDetails.AppName
+                try:
+                    if new_app_name == '':
+                        self.new_app_name = vm.AppTemplateName
+                    else:
+                        self.new_app_name = new_app_name
+                except:
+                    self.new_app_name = self.app_name
 
         self.server_address = server_address
         self.admin_user = admin_user
@@ -21,11 +28,6 @@ class SaveAppUtility:
         self.display_image_name = 'vm.png'
         self.display_image_url = display_image_url
 
-        if new_app_name == '':
-            self.new_app_name = self.app_name
-        else:
-            self.new_app_name = new_app_name
-
         self.display_image_result = None
         self.deploy_info = None
         self.saved_app_info = None
@@ -45,15 +47,19 @@ class SaveAppUtility:
                 break
 
     def get_display_image_from_url(self):
-        if self.display_image_url != '':
-            try:
+        try:
+            if self.display_image_url != '':
                 self.display_image_result = requests.get(self.display_image_url, allow_redirects=True).content
                 self.display_image_name = os.path.basename(self.display_image_url)
-            except Exception:
-                self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id,
-                                                                            'Issue downloading from Display Image URL... Using Default Display Image.')
-                self.display_image_result = None
+            else:
+                self.display_image_name = self.sandbox.automation_api.GetReservationAppTemplateImage(self.sandbox.id,
+                                                                                                     self.resource_name)
                 self.display_image_name = 'vm.png'
+        except:
+            self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id,
+                                                                        'Issue getting display image... Using default display image.')
+            self.display_image_result = None
+            self.display_image_name = 'vm.png'
 
     def save_app_info(self):
         command = [x.Name for x in self.sandbox.automation_api.GetResourceConnectedCommands(self.resource_name).Commands
